@@ -2,7 +2,7 @@
  * AudioPlayerViewController.swift
  * VLC for iOS
  *****************************************************************************
- * Copyright © 2022 VLC authors and VideoLAN
+ * Copyright © 2022-2023 VLC authors and VideoLAN
  *
  * Authors: Diogo Simao Marques <dogo@videolabs.io>
  *
@@ -66,7 +66,7 @@ class AudioPlayerViewController: PlayerViewController {
         mediaScrubProgressBar.updateBackgroundAlpha(with: 0.0)
         audioPlayerView.setupProgressView(with: mediaScrubProgressBar)
         audioPlayerView.setupExternalOutputView(with: externalOutputView)
-        self.view = audioPlayerView
+        setupAudioPlayerViewConstraints()
         setupOptionsNavigationBar()
         setupStatusLabel()
     }
@@ -93,10 +93,15 @@ class AudioPlayerViewController: PlayerViewController {
 
     override func viewWillDisappear(_ animated: Bool) {
         playerController.isInterfaceLocked = false
+        queueViewController?.hide()
     }
 
     // MARK: Public methods
 
+    override func minimizePlayer() {
+        delegate?.audioPlayerViewControllerDidMinimize(self)
+    }
+
     override func showPopup(_ popupView: PopupView, with contentView: UIView, accessoryViewsDelegate: PopupViewAccessoryViewsDelegate? = nil) {
         moreOptionsButton.isEnabled = false
         super.showPopup(popupView, with: contentView, accessoryViewsDelegate: accessoryViewsDelegate)
@@ -164,6 +169,18 @@ class AudioPlayerViewController: PlayerViewController {
 
     // MARK: - Private methods
 
+    private func setupAudioPlayerViewConstraints() {
+        audioPlayerView.translatesAutoresizingMaskIntoConstraints = false
+        view.addSubview(audioPlayerView)
+
+        NSLayoutConstraint.activate([
+            audioPlayerView.topAnchor.constraint(equalTo: view.topAnchor),
+            audioPlayerView.leadingAnchor.constraint(equalTo: view.leadingAnchor),
+            audioPlayerView.trailingAnchor.constraint(equalTo: view.trailingAnchor),
+            audioPlayerView.bottomAnchor.constraint(equalTo: view.bottomAnchor)
+        ])
+    }
+
     private func setupOptionsNavigationBar() {
         let padding: CGFloat = 10.0
 
@@ -225,22 +242,6 @@ class AudioPlayerViewController: PlayerViewController {
 
         playerController.isInterfaceLocked = !enabled
     }
-
-    private func getCurrentMediaTitle() -> String? {
-        if let audiotrack = VLCMLMedia.init(forPlaying: playbackService.currentlyPlayingMedia) {
-            return audiotrack.title
-        } else {
-            return playbackService.metadata.title
-        }
-    }
-
-    private func getCurrentMediaArtist() -> String? {
-        if let audiotrack = VLCMLMedia.init(forPlaying: playbackService.currentlyPlayingMedia) {
-            return audiotrack.albumTrackArtistName()
-        } else {
-            return nil
-        }
-    }
 }
 
 // MARK: - AudioPlayerViewDelegate
@@ -280,7 +281,7 @@ extension AudioPlayerViewController: AudioPlayerViewDelegate {
         return brightnessControlView
     }
 
-    func audioPlayerViewDeleagteGetVolumeSlider(_ audioPlayerView: AudioPlayerView) -> VolumeControlView {
+    func audioPlayerViewDelegateGetVolumeSlider(_ audioPlayerView: AudioPlayerView) -> VolumeControlView {
         return volumeControlView
     }
 }
@@ -291,10 +292,9 @@ extension AudioPlayerViewController {
     func prepare(forMediaPlayback playbackService: PlaybackService) {
         audioPlayerView.updatePlayButton(isPlaying: playbackService.isPlaying)
 
-        let title = getCurrentMediaTitle()
-        let artist = getCurrentMediaArtist()
-        audioPlayerView.updateLabels(title: title, artist: artist, isQueueHidden: isQueueHidden)
-        updateNavigationBar(with: isQueueHidden ? nil : playbackService.metadata.title)
+        let metadata = playbackService.metadata
+        audioPlayerView.updateLabels(title: metadata.title, artist: metadata.artist, isQueueHidden: isQueueHidden)
+        updateNavigationBar(with: isQueueHidden ? nil : metadata.title)
 
         if let qvc = queueViewController, !isQueueHidden {
             showPlayqueue(from: qvc)
@@ -329,19 +329,21 @@ extension AudioPlayerViewController {
         if currentState == .buffering {
             mediaDuration = playbackService.mediaDuration
         }
+
+        moreOptionsActionSheet.currentMediaHasChapters = currentMediaHasChapters
     }
 
     func displayMetadata(for playbackService: PlaybackService, metadata: VLCMetaData) {
-        let title = getCurrentMediaTitle()
-        let artist = getCurrentMediaArtist()
-        audioPlayerView.updateLabels(title: title, artist: artist, isQueueHidden: isQueueHidden)
+        audioPlayerView.updateLabels(title: metadata.title, artist: metadata.artist, isQueueHidden: isQueueHidden)
         updateNavigationBar(with: isQueueHidden ? nil : metadata.title)
 
-        audioPlayerView.setupThumbnailView()
-        audioPlayerView.setupBackgroundColor()
+        if metadata.artworkImage != audioPlayerView.thumbnailImageView.image {
+            audioPlayerView.setupThumbnailView()
+            audioPlayerView.setupBackgroundColor()
 
-        if let qvc = queueViewController, !isQueueHidden {
-            qvc.reloadBackground(with: audioPlayerView.thumbnailImageView.image)
+            if let qvc = queueViewController, !isQueueHidden {
+                qvc.reloadBackground(with: audioPlayerView.thumbnailImageView.image)
+            }
         }
     }
 }
@@ -380,10 +382,9 @@ extension AudioPlayerViewController {
     }
 
     func mediaNavigationBarDidToggleQueueView(_ mediaNavigationBar: MediaNavigationBar) {
-        let title = getCurrentMediaTitle()
-        let artist = getCurrentMediaArtist()
-        audioPlayerView.updateLabels(title: title, artist: artist, isQueueHidden: !isQueueHidden)
-        updateNavigationBar(with: !isQueueHidden ? nil : playbackService.metadata.title)
+        let metadata = playbackService.metadata
+        audioPlayerView.updateLabels(title: metadata.title, artist: metadata.artist, isQueueHidden: !isQueueHidden)
+        updateNavigationBar(with: !isQueueHidden ? nil : metadata.title)
 
         var isThumbnailViewHidden: Bool = isQueueHidden
         if playbackService.isPlayingOnExternalScreen() {
